# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/admin/v1/client_key_admin.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/admin/v1/client_key_admin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import client_key_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_client__key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,olvid/daemon/admin/v1/client_key_admin.proto\x12\x15olvid.daemon.admin.v1\x1a*olvid/daemon/datatypes/v1/client_key.proto\"j\n\x14\x43lientKeyListRequest\x12G\n\x06\x66ilter\x18\x01 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.ClientKeyFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"^\n\x15\x43lientKeyListResponse\x12\x45\n\x0b\x63lient_keys\x18\x01 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.ClientKeyR\nclientKeys\"4\n\x13\x43lientKeyGetRequest\x12\x1d\n\nclient_key\x18\x01 \x01(\tR\tclientKey\"[\n\x14\x43lientKeyGetResponse\x12\x43\n\nclient_key\x18\x01 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.ClientKeyR\tclientKey\"J\n\x13\x43lientKeyNewRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1f\n\x0bidentity_id\x18\x02 \x01(\x04R\nidentityId\"[\n\x14\x43lientKeyNewResponse\x12\x43\n\nclient_key\x18\x01 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.ClientKeyR\tclientKey\"7\n\x16\x43lientKeyDeleteRequest\x12\x1d\n\nclient_key\x18\x01 \x01(\tR\tclientKey\"\x19\n\x17\x43lientKeyDeleteResponseB\xb8\x01\n\x19\x63om.olvid.daemon.admin.v1B\x13\x43lientKeyAdminProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODA\xaa\x02\x15Olvid.Daemon.Admin.V1\xca\x02\x15Olvid\\Daemon\\Admin\\V1\xe2\x02!Olvid\\Daemon\\Admin\\V1\\GPBMetadata\xea\x02\x18Olvid::Daemon::Admin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.admin.v1.client_key_admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.olvid.daemon.admin.v1B\023ClientKeyAdminProtoP\001Z\017olvid.io/daemon\242\002\003ODA\252\002\025Olvid.Daemon.Admin.V1\312\002\025Olvid\\Daemon\\Admin\\V1\342\002!Olvid\\Daemon\\Admin\\V1\\GPBMetadata\352\002\030Olvid::Daemon::Admin::V1'
  _globals['_CLIENTKEYLISTREQUEST']._serialized_start=115
  _globals['_CLIENTKEYLISTREQUEST']._serialized_end=221
  _globals['_CLIENTKEYLISTRESPONSE']._serialized_start=223
  _globals['_CLIENTKEYLISTRESPONSE']._serialized_end=317
  _globals['_CLIENTKEYGETREQUEST']._serialized_start=319
  _globals['_CLIENTKEYGETREQUEST']._serialized_end=371
  _globals['_CLIENTKEYGETRESPONSE']._serialized_start=373
  _globals['_CLIENTKEYGETRESPONSE']._serialized_end=464
  _globals['_CLIENTKEYNEWREQUEST']._serialized_start=466
  _globals['_CLIENTKEYNEWREQUEST']._serialized_end=540
  _globals['_CLIENTKEYNEWRESPONSE']._serialized_start=542
  _globals['_CLIENTKEYNEWRESPONSE']._serialized_end=633
  _globals['_CLIENTKEYDELETEREQUEST']._serialized_start=635
  _globals['_CLIENTKEYDELETEREQUEST']._serialized_end=690
  _globals['_CLIENTKEYDELETERESPONSE']._serialized_start=692
  _globals['_CLIENTKEYDELETERESPONSE']._serialized_end=717
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/identity_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/identity_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import identity_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9olvid/daemon/notification/v1/identity_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a(olvid/daemon/datatypes/v1/identity.proto\"M\n&SubscribeToIdentityCreatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"^\n\x1bIdentityCreatedNotification\x12?\n\x08identity\x18\x01 \x01(\x0b\x32#.olvid.daemon.datatypes.v1.IdentityR\x08identity\"M\n&SubscribeToIdentityDeletedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"^\n\x1bIdentityDeletedNotification\x12?\n\x08identity\x18\x01 \x01(\x0b\x32#.olvid.daemon.datatypes.v1.IdentityR\x08identity\"M\n&SubscribeToIdentityUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\xbc\x01\n\"IdentityDetailsUpdatedNotification\x12?\n\x08identity\x18\x01 \x01(\x0b\x32#.olvid.daemon.datatypes.v1.IdentityR\x08identity\x12U\n\x10previous_details\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsR\x0fpreviousDetailsB\xe2\x01\n com.olvid.daemon.notification.v1B\x1aIdentityNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.identity_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\032IdentityNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOIDENTITYCREATEDNOTIFICATION']._serialized_start=133
  _globals['_SUBSCRIBETOIDENTITYCREATEDNOTIFICATION']._serialized_end=210
  _globals['_IDENTITYCREATEDNOTIFICATION']._serialized_start=212
  _globals['_IDENTITYCREATEDNOTIFICATION']._serialized_end=306
  _globals['_SUBSCRIBETOIDENTITYDELETEDNOTIFICATION']._serialized_start=308
  _globals['_SUBSCRIBETOIDENTITYDELETEDNOTIFICATION']._serialized_end=385
  _globals['_IDENTITYDELETEDNOTIFICATION']._serialized_start=387
  _globals['_IDENTITYDELETEDNOTIFICATION']._serialized_end=481
  _globals['_SUBSCRIBETOIDENTITYUPDATEDNOTIFICATION']._serialized_start=483
  _globals['_SUBSCRIBETOIDENTITYUPDATEDNOTIFICATION']._serialized_end=560
  _globals['_IDENTITYDETAILSUPDATEDNOTIFICATION']._serialized_start=563
  _globals['_IDENTITYDETAILSUPDATEDNOTIFICATION']._serialized_end=751
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/attachment_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/attachment_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import attachment_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_attachment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1olvid/daemon/command/v1/attachment_commands.proto\x12\x17olvid.daemon.command.v1\x1a*olvid/daemon/datatypes/v1/attachment.proto\"l\n\x15\x41ttachmentListRequest\x12H\n\x06\x66ilter\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.AttachmentFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"a\n\x16\x41ttachmentListResponse\x12G\n\x0b\x61ttachments\x18\x01 \x03(\x0b\x32%.olvid.daemon.datatypes.v1.AttachmentR\x0b\x61ttachments\"d\n\x14\x41ttachmentGetRequest\x12L\n\rattachment_id\x18\x01 \x01(\x0b\x32\'.olvid.daemon.datatypes.v1.AttachmentIdR\x0c\x61ttachmentId\"^\n\x15\x41ttachmentGetResponse\x12\x45\n\nattachment\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.AttachmentR\nattachment\"\xaf\x01\n\x17\x41ttachmentDeleteRequest\x12L\n\rattachment_id\x18\x01 \x01(\x0b\x32\'.olvid.daemon.datatypes.v1.AttachmentIdR\x0c\x61ttachmentId\x12\x30\n\x11\x64\x65lete_everywhere\x18\x02 \x01(\x08H\x00R\x10\x64\x65leteEverywhere\x88\x01\x01\x42\x14\n\x12_delete_everywhere\"\x1a\n\x18\x41ttachmentDeleteResponse\"i\n\x19\x41ttachmentDownloadRequest\x12L\n\rattachment_id\x18\x01 \x01(\x0b\x32\'.olvid.daemon.datatypes.v1.AttachmentIdR\x0c\x61ttachmentId\"2\n\x1a\x41ttachmentDownloadResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunkB\xc6\x01\n\x1b\x63om.olvid.daemon.command.v1B\x17\x41ttachmentCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.attachment_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\027AttachmentCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_ATTACHMENTLISTREQUEST']._serialized_start=122
  _globals['_ATTACHMENTLISTREQUEST']._serialized_end=230
  _globals['_ATTACHMENTLISTRESPONSE']._serialized_start=232
  _globals['_ATTACHMENTLISTRESPONSE']._serialized_end=329
  _globals['_ATTACHMENTGETREQUEST']._serialized_start=331
  _globals['_ATTACHMENTGETREQUEST']._serialized_end=431
  _globals['_ATTACHMENTGETRESPONSE']._serialized_start=433
  _globals['_ATTACHMENTGETRESPONSE']._serialized_end=527
  _globals['_ATTACHMENTDELETEREQUEST']._serialized_start=530
  _globals['_ATTACHMENTDELETEREQUEST']._serialized_end=705
  _globals['_ATTACHMENTDELETERESPONSE']._serialized_start=707
  _globals['_ATTACHMENTDELETERESPONSE']._serialized_end=733
  _globals['_ATTACHMENTDOWNLOADREQUEST']._serialized_start=735
  _globals['_ATTACHMENTDOWNLOADREQUEST']._serialized_end=840
  _globals['_ATTACHMENTDOWNLOADRESPONSE']._serialized_start=842
  _globals['_ATTACHMENTDOWNLOADRESPONSE']._serialized_end=892
# @@protoc_insertion_point(module_scope)



####
# WARNING: DO NOT EDIT: this code is automatically generated, see overlay_generator/generate_protobuf_overlay
####

from ..notifications import *
from ..commands import *
from ..admin import *

from typing import Union


NotificationMessageType = Union[SubscribeToAttachmentReceivedNotification, AttachmentReceivedNotification, SubscribeToAttachmentUploadedNotification, AttachmentUploadedNotification, SubscribeToCallIncomingCallNotification, CallIncomingCallNotification, SubscribeToCallRingingNotification, CallRingingNotification, SubscribeToCallAcceptedNotification, CallAcceptedNotification, SubscribeToCallDeclinedNotification, CallDeclinedNotification, SubscribeToCallBusyNotification, CallBusyNotification, SubscribeToCallEndedNotification, CallEndedNotification, SubscribeToContactNewNotification, ContactNewNotification, SubscribeToContactDeletedNotification, ContactDeletedNotification, SubscribeToContactDetailsUpdatedNotification, ContactDetailsUpdatedNotification, SubscribeToContactPhotoUpdatedNotification, ContactPhotoUpdatedNotification, SubscribeToDiscussionNewNotification, DiscussionNewNotification, SubscribeToDiscussionLockedNotification, DiscussionLockedNotification, SubscribeToDiscussionTitleUpdatedNotification, DiscussionTitleUpdatedNotification, SubscribeToDiscussionSettingsUpdatedNotification, DiscussionSettingsUpdatedNotification, SubscribeToGroupNewNotification, GroupNewNotification, SubscribeToGroupDeletedNotification, GroupDeletedNotification, SubscribeToGroupNameUpdatedNotification, GroupNameUpdatedNotification, SubscribeToGroupPhotoUpdatedNotification, GroupPhotoUpdatedNotification, SubscribeToGroupDescriptionUpdatedNotification, GroupDescriptionUpdatedNotification, SubscribeToGroupPendingMemberAddedNotification, GroupPendingMemberAddedNotification, SubscribeToGroupPendingMemberRemovedNotification, GroupPendingMemberRemovedNotification, SubscribeToGroupMemberJoinedNotification, GroupMemberJoinedNotification, SubscribeToGroupMemberLeftNotification, GroupMemberLeftNotification, SubscribeToGroupOwnPermissionsUpdatedNotification, GroupOwnPermissionsUpdatedNotification, SubscribeToGroupMemberPermissionsUpdatedNotification, GroupMemberPermissionsUpdatedNotification, SubscribeToIdentityCreatedNotification, IdentityCreatedNotification, SubscribeToIdentityDeletedNotification, IdentityDeletedNotification, SubscribeToIdentityUpdatedNotification, IdentityDetailsUpdatedNotification, SubscribeToInvitationReceivedNotification, InvitationReceivedNotification, SubscribeToInvitationSentNotification, InvitationSentNotification, SubscribeToInvitationDeletedNotification, InvitationDeletedNotification, SubscribeToInvitationUpdatedNotification, InvitationUpdatedNotification, SubscribeToMessageReceivedNotification, MessageReceivedNotification, SubscribeToMessageSentNotification, MessageSentNotification, SubscribeToMessageDeletedNotification, MessageDeletedNotification, SubscribeToMessageBodyUpdatedNotification, MessageBodyUpdatedNotification, SubscribeToMessageUploadedNotification, MessageUploadedNotification, SubscribeToMessageDeliveredNotification, MessageDeliveredNotification, SubscribeToMessageReadNotification, MessageReadNotification, SubscribeToMessageLocationReceivedNotification, MessageLocationReceivedNotification, SubscribeToMessageLocationSentNotification, MessageLocationSentNotification, SubscribeToMessageLocationSharingStartNotification, MessageLocationSharingStartNotification, SubscribeToMessageLocationSharingUpdateNotification, MessageLocationSharingUpdateNotification, SubscribeToMessageLocationSharingEndNotification, MessageLocationSharingEndNotification, SubscribeToMessageReactionAddedNotification, MessageReactionAddedNotification, SubscribeToMessageReactionUpdatedNotification, MessageReactionUpdatedNotification, SubscribeToMessageReactionRemovedNotification, MessageReactionRemovedNotification]
CommandRequestMessageType = Union[BackupKeyGetRequest, BackupKeyRenewRequest, BackupGetRequest, BackupNowRequest, BackupRestoreDaemonRequest, BackupRestoreAdminBackupRequest, BackupRestoreProfileSnapshotRequest, ClientKeyListRequest, ClientKeyGetRequest, ClientKeyNewRequest, ClientKeyDeleteRequest, IdentityListRequest, IdentityAdminGetRequest, IdentityAdminGetBytesIdentifierRequest, IdentityAdminGetInvitationLinkRequest, IdentityAdminDownloadPhotoRequest, IdentityNewRequest, IdentityKeycloakNewRequest, IdentityDeleteRequest, AttachmentListRequest, AttachmentGetRequest, AttachmentDeleteRequest, AttachmentDownloadRequest, CallStartDiscussionCallRequest, CallStartCustomCallRequest, ContactListRequest, ContactGetRequest, ContactGetBytesIdentifierRequest, ContactGetInvitationLinkRequest, ContactDeleteRequest, ContactIntroductionRequest, ContactInviteToOneToOneDiscussionRequest, ContactDowngradeOneToOneDiscussionRequest, ContactDownloadPhotoRequest, ContactRecreateChannelsRequest, DiscussionListRequest, DiscussionGetRequest, DiscussionGetBytesIdentifierRequest, DiscussionGetByContactRequest, DiscussionGetByGroupRequest, DiscussionEmptyRequest, DiscussionDownloadPhotoRequest, DiscussionLockedListRequest, DiscussionLockedDeleteRequest, GroupListRequest, GroupGetRequest, GroupGetBytesIdentifierRequest, GroupNewStandardGroupRequest, GroupNewControlledGroupRequest, GroupNewReadOnlyGroupRequest, GroupNewAdvancedGroupRequest, GroupDisbandRequest, GroupLeaveRequest, GroupUpdateRequest, GroupUnsetPhotoRequest, GroupSetPhotoRequest, GroupDownloadPhotoRequest, IdentityGetRequest, IdentityGetBytesIdentifierRequest, IdentityGetInvitationLinkRequest, IdentityUpdateDetailsRequest, IdentityRemovePhotoRequest, IdentitySetPhotoRequest, IdentityDownloadPhotoRequest, IdentityGetApiKeyStatusRequest, IdentitySetApiKeyRequest, IdentitySetConfigurationLinkRequest, InvitationListRequest, InvitationGetRequest, InvitationNewRequest, InvitationAcceptRequest, InvitationDeclineRequest, InvitationSasRequest, InvitationDeleteRequest, KeycloakBindIdentityRequest, KeycloakUnbindIdentityRequest, KeycloakUserListRequest, KeycloakAddUserAsContactRequest, KeycloakGetApiCredentialsRequest, MessageListRequest, MessageGetRequest, MessageRefreshRequest, MessageDeleteRequest, MessageSendRequest, MessageSendWithAttachmentsRequest, MessageSendLocationRequest, MessageStartLocationSharingRequest, MessageUpdateLocationSharingRequest, MessageEndLocationSharingRequest, MessageReactRequest, MessageUpdateBodyRequest, SettingsIdentityGetRequest, SettingsIdentitySetRequest, SettingsDiscussionGetRequest, SettingsDiscussionSetRequest, StorageListRequest, StorageGetRequest, StorageSetRequest, StorageUnsetRequest, DiscussionStorageListRequest, DiscussionStorageGetRequest, DiscussionStorageSetRequest, DiscussionStorageUnsetRequest, PingRequest, DaemonVersionRequest, AuthenticationTestRequest, AuthenticationAdminTestRequest]
CommandResponseMessageType = Union[BackupKeyGetResponse, BackupKeyRenewResponse, BackupGetResponse, BackupNowResponse, BackupRestoreDaemonResponse, BackupRestoreAdminBackupResponse, BackupRestoreProfileSnapshotResponse, ClientKeyListResponse, ClientKeyGetResponse, ClientKeyNewResponse, ClientKeyDeleteResponse, IdentityListResponse, IdentityAdminGetResponse, IdentityAdminGetBytesIdentifierResponse, IdentityAdminGetInvitationLinkResponse, IdentityAdminDownloadPhotoResponse, IdentityNewResponse, IdentityKeycloakNewResponse, IdentityDeleteResponse, AttachmentListResponse, AttachmentGetResponse, AttachmentDeleteResponse, AttachmentDownloadResponse, CallStartDiscussionCallResponse, CallStartCustomCallResponse, ContactListResponse, ContactGetResponse, ContactGetBytesIdentifierResponse, ContactGetInvitationLinkResponse, ContactDeleteResponse, ContactIntroductionResponse, ContactInviteToOneToOneDiscussionResponse, ContactDowngradeOneToOneDiscussionResponse, ContactDownloadPhotoResponse, ContactRecreateChannelsResponse, DiscussionListResponse, DiscussionGetResponse, DiscussionGetBytesIdentifierResponse, DiscussionGetByContactResponse, DiscussionGetByGroupResponse, DiscussionEmptyResponse, DiscussionDownloadPhotoResponse, DiscussionLockedListResponse, DiscussionLockedDeleteResponse, GroupListResponse, GroupGetResponse, GroupGetBytesIdentifierResponse, GroupNewStandardGroupResponse, GroupNewControlledGroupResponse, GroupNewReadOnlyGroupResponse, GroupNewAdvancedGroupResponse, GroupDisbandResponse, GroupLeaveResponse, GroupUpdateResponse, GroupUnsetPhotoResponse, GroupSetPhotoResponse, GroupDownloadPhotoResponse, IdentityGetResponse, IdentityGetBytesIdentifierResponse, IdentityGetInvitationLinkResponse, IdentityUpdateDetailsResponse, IdentityRemovePhotoResponse, IdentitySetPhotoResponse, IdentityDownloadPhotoResponse, IdentityGetApiKeyStatusResponse, IdentitySetApiKeyResponse, IdentitySetConfigurationLinkResponse, InvitationListResponse, InvitationGetResponse, InvitationNewResponse, InvitationAcceptResponse, InvitationDeclineResponse, InvitationSasResponse, InvitationDeleteResponse, KeycloakBindIdentityResponse, KeycloakUnbindIdentityResponse, KeycloakUserListResponse, KeycloakAddUserAsContactResponse, KeycloakGetApiCredentialsResponse, MessageListResponse, MessageGetResponse, MessageRefreshResponse, MessageDeleteResponse, MessageSendResponse, MessageSendWithAttachmentsResponse, MessageSendLocationResponse, MessageStartLocationSharingResponse, MessageUpdateLocationSharingResponse, MessageEndLocationSharingResponse, MessageReactResponse, MessageUpdateBodyResponse, SettingsIdentityGetResponse, SettingsIdentitySetResponse, SettingsDiscussionGetResponse, SettingsDiscussionSetResponse, StorageListResponse, StorageGetResponse, StorageSetResponse, StorageUnsetResponse, DiscussionStorageListResponse, DiscussionStorageGetResponse, DiscussionStorageSetResponse, DiscussionStorageUnsetResponse, PingResponse, DaemonVersionResponse, AuthenticationTestResponse, AuthenticationAdminTestResponse]



import logging

from ClientHolder import ClientHolder, ClientWrapper
from olvid import datatypes, listeners

test_failed: bool = False

async def location_send(c1: ClientWrapper, c2: ClientWrapper):
	discussion_1, discussion_2 = await c1.get_discussion_associated_to_another_client(c2), await c2.get_discussion_associated_to_another_client(c1)
	contact_1, contact_2 = await c1.get_contact_associated_to_another_client(c2), await c2.get_contact_associated_to_another_client(c1)

	# prepare expected payloads
	expected_body: str = "https://maps.google.com/?q=48.87174+2.32649"
	expected_location_1: datatypes.MessageLocation = datatypes.MessageLocation(type=datatypes.MessageLocation.LocationType.LOCATION_TYPE_SEND, latitude=48.87174, longitude=2.32649, precision=68, altitude=854)
	expected_message_1: datatypes.Message = datatypes.Message(discussion_id=discussion_1.id, body=expected_body, attachments_count=0, message_location=expected_location_1)
	expected_location_2: datatypes.MessageLocation = datatypes.MessageLocation(type=datatypes.MessageLocation.LocationType.LOCATION_TYPE_SEND, latitude=expected_location_1.latitude, longitude=expected_location_1.longitude, altitude=expected_location_1.altitude, precision=expected_location_1.precision)
	expected_message_2: datatypes.Message = datatypes.Message(discussion_id=discussion_2.id, body=expected_body, sender_id=contact_2.id, attachments_count=0, message_location=expected_location_2)

	# prepare notification bots
	bots = [
		c1.create_notification_bot(listeners.MessageSentListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_SENT), count=1)),
		c1.create_notification_bot(listeners.MessageLocationSentListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SENT), count=1)),
		c1.create_notification_bot(listeners.MessageUploadedListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_UPLOADED), count=1)),
		c1.create_notification_bot(listeners.MessageDeliveredListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_DELIVERED), count=1)),
		c1.create_notification_bot(listeners.MessageReadListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_READ), count=1)),
		c2.create_notification_bot(listeners.MessageReceivedListener(handler=c2.get_check_content_handler(expected_message_2, notification_type=listeners.NOTIFICATIONS.MESSAGE_RECEIVED), count=1)),
		c2.create_notification_bot(listeners.MessageLocationReceivedListener(handler=c2.get_check_content_handler(expected_message_2, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_RECEIVED), count=1)),
	]

	location_message: datatypes.Message = await c1.message_send_location(discussion_id=discussion_1.id, latitude=expected_location_1.latitude, longitude=expected_location_1.longitude, altitude=expected_location_1.altitude, precision=expected_location_1.precision)
	assert location_message._test_assertion(expected_message_1), "Returned message is not as expected"

	for bot in bots:
		await bot.wait_for_listeners_end()


async def start_location_sharing(c1: ClientWrapper, c2: ClientWrapper) -> tuple[datatypes.Message, datatypes.Message]:
	discussion_1, discussion_2 = await c1.get_discussion_associated_to_another_client(c2), await c2.get_discussion_associated_to_another_client(c1)
	contact_1, contact_2 = await c1.get_contact_associated_to_another_client(c2), await c2.get_contact_associated_to_another_client(c1)

	if len([m async for m in c1.message_list(filter=datatypes.MessageFilter(location=datatypes.MessageFilter.Location.LOCATION_IS_SHARING))]) > 0:
		logging.warning("Found a running sharing location message, next warning on LOCATION_SHARING_END is normal")

	# prepare expected payloads
	expected_body: str = "https://maps.google.com/?q=48.87175+2.32650"
	expected_location_1: datatypes.MessageLocation = datatypes.MessageLocation(type=datatypes.MessageLocation.LocationType.LOCATION_TYPE_SHARING, latitude=48.87175, longitude=2.32650, precision=75, altitude=458)
	expected_message_1: datatypes.Message = datatypes.Message(discussion_id=discussion_1.id, body=expected_body, attachments_count=0, message_location=expected_location_1)
	expected_location_2: datatypes.MessageLocation = datatypes.MessageLocation(type=datatypes.MessageLocation.LocationType.LOCATION_TYPE_SHARING, latitude=expected_location_1.latitude, longitude=expected_location_1.longitude, altitude=expected_location_1.altitude, precision=expected_location_1.precision)
	expected_message_2: datatypes.Message = datatypes.Message(discussion_id=discussion_2.id, body=expected_body, sender_id=contact_2.id, attachments_count=0, message_location=expected_location_2)

	# prepare notification bots
	location_sharing_start_notif: list = []
	bots = [
		c1.create_notification_bot(listeners.MessageSentListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_SENT), count=1)),
		c1.create_notification_bot(listeners.MessageUploadedListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_UPLOADED), count=1)),
		c1.create_notification_bot(listeners.MessageDeliveredListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_DELIVERED), count=1)),
		c1.create_notification_bot(listeners.MessageReadListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_READ), count=1)),
		c1.create_notification_bot(listeners.MessageLocationSharingStartListener(handler=c1.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SHARING_START), count=1)),

		c2.create_notification_bot(listeners.MessageReceivedListener(handler=c2.get_check_content_handler(expected_message_2, notification_type=listeners.NOTIFICATIONS.MESSAGE_RECEIVED), count=1)),
		c2.create_notification_bot(listeners.MessageLocationSharingStartListener(handler=c2.get_check_content_handler(expected_message_2, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SHARING_START), count=1)),
		c2.create_notification_bot(listeners.MessageLocationSharingStartListener(handler=c2.get_store_notif_handler(location_sharing_start_notif, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SHARING_START), count=1)),
	]

	sharing_location_message_1: datatypes.Message = await c1.message_start_location_sharing(discussion_id=discussion_1.id, latitude=expected_location_1.latitude, longitude=expected_location_1.longitude, altitude=expected_location_1.altitude, precision=expected_location_1.precision)
	assert sharing_location_message_1._test_assertion(expected_message_1), "Returned message is not as expected"

	for bot in bots:
		await bot.wait_for_listeners_end()

	sharing_location_message_2: datatypes.Message = location_sharing_start_notif[0]
	return sharing_location_message_1, sharing_location_message_2

async def update_location_sharing(c1: ClientWrapper, c2: ClientWrapper, sharing_location_message_1: datatypes.Message, sharing_location_message_2: datatypes.Message, new_location: datatypes.MessageLocation) -> tuple[datatypes.Message, datatypes.Message]:
	# prepare expected payloads
	expected_previous_location_1: datatypes.MessageLocation = sharing_location_message_1.message_location._clone()
	expected_previous_location_2: datatypes.MessageLocation = sharing_location_message_2.message_location._clone()
	assert expected_previous_location_1._test_assertion(expected_previous_location_2), f"Previous location are not the same on both side: {expected_previous_location_1} != {expected_previous_location_2}"
	expected_body: str = f"https://maps.google.com/?q={new_location.latitude:.5f}+{new_location.longitude:.5f}"
	expected_message_1: datatypes.Message = sharing_location_message_1._clone()
	expected_message_2: datatypes.Message = sharing_location_message_2._clone()
	expected_message_1.body = expected_body
	expected_message_1.message_location = new_location._clone()
	expected_message_2.body = expected_body
	expected_message_2.message_location = new_location._clone()

	# prepare notification bots
	location_sharing_update_notif = []
	bots = [
		c1.create_notification_bot(listeners.MessageLocationSharingUpdateListener(handler=c2.get_check_content_handler(expected_message_1, expected_previous_location_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SHARING_UPDATE), count=1)),
		c2.create_notification_bot(listeners.MessageLocationSharingUpdateListener(handler=c2.get_check_content_handler(expected_message_2, expected_previous_location_2, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SHARING_UPDATE), count=1)),
		c2.create_notification_bot(listeners.MessageLocationSharingUpdateListener(handler=c2.get_store_notif_handler(location_sharing_update_notif, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SHARING_UPDATE), count=1)),
	]

	updated_message: datatypes.Message = await c1.message_update_location_sharing(message_id=sharing_location_message_1.id, latitude=new_location.latitude, longitude=new_location.longitude, altitude=new_location.altitude, precision=new_location.precision)
	assert updated_message._test_assertion(expected_message_1), "Returned message is not as expected"

	for bot in bots:
		await bot.wait_for_listeners_end()

	return updated_message, location_sharing_update_notif[0]


async def end_location_sharing(c1: ClientWrapper, c2: ClientWrapper, sharing_location_message_1: datatypes.Message, sharing_location_message_2: datatypes.Message):
	# prepare expected payloads
	expected_message_1: datatypes.Message = sharing_location_message_1._clone()
	expected_message_1.message_location.type = datatypes.MessageLocation.LocationType.LOCATION_TYPE_SHARING_FINISHED
	expected_message_2: datatypes.Message = sharing_location_message_2._clone()
	expected_message_2.message_location.type = datatypes.MessageLocation.LocationType.LOCATION_TYPE_SHARING_FINISHED

	# prepare notification bots
	location_sharing_update_notif = []
	bots = [
		c1.create_notification_bot(listeners.MessageLocationSharingEndListener(handler=c2.get_check_content_handler(expected_message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SHARING_END), count=1)),
		c2.create_notification_bot(listeners.MessageLocationSharingEndListener(handler=c2.get_check_content_handler(expected_message_2, notification_type=listeners.NOTIFICATIONS.MESSAGE_LOCATION_SHARING_END), count=1)),
	]

	returned_message: datatypes.Message = await c1.message_end_location_sharing(message_id=sharing_location_message_1.id)
	assert returned_message._test_assertion(expected_message_1), "Returned message is not as expected"

	for bot in bots:
		await bot.wait_for_listeners_end()

# noinspection PyUnusedLocal
async def test_location(client_holder: ClientHolder, fast_mode=False):
	for c1, c2 in client_holder.get_one_client_pair_and_reverse():
		logging.info(f"{c1.identity.id} <-> {c2.identity.id}: send location")
		await location_send(c1, c2)
		logging.info(f"{c1.identity.id} <-> {c2.identity.id}: start location sharing")
		m1, m2 = await start_location_sharing(c1, c2)
		logging.info(f"{c1.identity.id} <-> {c2.identity.id}: update location sharing")
		m1, m2 = await update_location_sharing(c1, c2, m1, m2, new_location=datatypes.MessageLocation(latitude=13.1313, longitude=12.1212, precision=4, altitude=15))
		m1, m2 = await update_location_sharing(c1, c2, m1, m2, new_location=datatypes.MessageLocation(latitude=15.1515, longitude=16.1616, precision=89, altitude=789))
		logging.info(f"{c1.identity.id} <-> {c2.identity.id}: end location sharing")
		await end_location_sharing(c1, c2, m1, m2)

		if test_failed:
			raise Exception("Test was marked as failed")



from .datatypes import AttachmentId, Attachment, AttachmentFilter, Backup, CallParticipantId, ClientKey, ClientKeyFilter, Contact, ContactFilter, Discussion, DiscussionFilter, Group, GroupMember, PendingGroupMember, GroupMemberPermissions, GroupFilter, GroupMemberFilter, PendingGroupMemberFilter, GroupPermissionFilter, IdentityDetails, Identity, IdentityFilter, Invitation, InvitationFilter, KeycloakUser, KeycloakUserFilter, KeycloakApiCredentials, MessageId, Message, MessageEphemerality, MessageReaction, MessageLocation, MessageFilter, ReactionFilter, IdentitySettings, DiscussionSettings, StorageElement, StorageElementFilter

del datatypes



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/settings_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/settings_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import settings_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/olvid/daemon/command/v1/settings_commands.proto\x12\x17olvid.daemon.command.v1\x1a(olvid/daemon/datatypes/v1/settings.proto\"\x1c\n\x1aSettingsIdentityGetRequest\"w\n\x1bSettingsIdentityGetResponse\x12X\n\x11identity_settings\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.IdentitySettingsR\x10identitySettings\"v\n\x1aSettingsIdentitySetRequest\x12X\n\x11identity_settings\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.IdentitySettingsR\x10identitySettings\"w\n\x1bSettingsIdentitySetResponse\x12X\n\x11identity_settings\x18\x01 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.IdentitySettingsR\x10identitySettings\"C\n\x1cSettingsDiscussionGetRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\"\x7f\n\x1dSettingsDiscussionGetResponse\x12^\n\x13\x64iscussion_settings\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x12\x64iscussionSettings\"~\n\x1cSettingsDiscussionSetRequest\x12^\n\x13\x64iscussion_settings\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x12\x64iscussionSettings\"\x7f\n\x1dSettingsDiscussionSetResponse\x12^\n\x13\x64iscussion_settings\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x12\x64iscussionSettingsB\xc4\x01\n\x1b\x63om.olvid.daemon.command.v1B\x15SettingsCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.settings_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\025SettingsCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_SETTINGSIDENTITYGETREQUEST']._serialized_start=118
  _globals['_SETTINGSIDENTITYGETREQUEST']._serialized_end=146
  _globals['_SETTINGSIDENTITYGETRESPONSE']._serialized_start=148
  _globals['_SETTINGSIDENTITYGETRESPONSE']._serialized_end=267
  _globals['_SETTINGSIDENTITYSETREQUEST']._serialized_start=269
  _globals['_SETTINGSIDENTITYSETREQUEST']._serialized_end=387
  _globals['_SETTINGSIDENTITYSETRESPONSE']._serialized_start=389
  _globals['_SETTINGSIDENTITYSETRESPONSE']._serialized_end=508
  _globals['_SETTINGSDISCUSSIONGETREQUEST']._serialized_start=510
  _globals['_SETTINGSDISCUSSIONGETREQUEST']._serialized_end=577
  _globals['_SETTINGSDISCUSSIONGETRESPONSE']._serialized_start=579
  _globals['_SETTINGSDISCUSSIONGETRESPONSE']._serialized_end=706
  _globals['_SETTINGSDISCUSSIONSETREQUEST']._serialized_start=708
  _globals['_SETTINGSDISCUSSIONSETREQUEST']._serialized_end=834
  _globals['_SETTINGSDISCUSSIONSETRESPONSE']._serialized_start=836
  _globals['_SETTINGSDISCUSSIONSETRESPONSE']._serialized_end=963
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/call_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/call_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import call_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_call__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5olvid/daemon/notification/v1/call_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a$olvid/daemon/datatypes/v1/call.proto\"N\n\'SubscribeToCallIncomingCallNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x9e\x02\n\x1c\x43\x61llIncomingCallNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12#\n\rdiscussion_id\x18\x02 \x01(\x04R\x0c\x64iscussionId\x12S\n\x0eparticipant_id\x18\x03 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\x12.\n\x13\x63\x61ller_display_name\x18\x04 \x01(\tR\x11\x63\x61llerDisplayName\x12+\n\x11participant_count\x18\x05 \x01(\rR\x10participantCount\"I\n\"SubscribeToCallRingingNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x97\x01\n\x17\x43\x61llRingingNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12S\n\x0eparticipant_id\x18\x02 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\"J\n#SubscribeToCallAcceptedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x98\x01\n\x18\x43\x61llAcceptedNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12S\n\x0eparticipant_id\x18\x02 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\"J\n#SubscribeToCallDeclinedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x98\x01\n\x18\x43\x61llDeclinedNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12S\n\x0eparticipant_id\x18\x02 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\"F\n\x1fSubscribeToCallBusyNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"\x94\x01\n\x14\x43\x61llBusyNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifier\x12S\n\x0eparticipant_id\x18\x02 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.CallParticipantIdR\rparticipantId\"G\n SubscribeToCallEndedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x42\x08\n\x06_count\"@\n\x15\x43\x61llEndedNotification\x12\'\n\x0f\x63\x61ll_identifier\x18\x01 \x01(\tR\x0e\x63\x61llIdentifierB\xde\x01\n com.olvid.daemon.notification.v1B\x16\x43\x61llNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.call_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\026CallNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOCALLINCOMINGCALLNOTIFICATION']._serialized_start=125
  _globals['_SUBSCRIBETOCALLINCOMINGCALLNOTIFICATION']._serialized_end=203
  _globals['_CALLINCOMINGCALLNOTIFICATION']._serialized_start=206
  _globals['_CALLINCOMINGCALLNOTIFICATION']._serialized_end=492
  _globals['_SUBSCRIBETOCALLRINGINGNOTIFICATION']._serialized_start=494
  _globals['_SUBSCRIBETOCALLRINGINGNOTIFICATION']._serialized_end=567
  _globals['_CALLRINGINGNOTIFICATION']._serialized_start=570
  _globals['_CALLRINGINGNOTIFICATION']._serialized_end=721
  _globals['_SUBSCRIBETOCALLACCEPTEDNOTIFICATION']._serialized_start=723
  _globals['_SUBSCRIBETOCALLACCEPTEDNOTIFICATION']._serialized_end=797
  _globals['_CALLACCEPTEDNOTIFICATION']._serialized_start=800
  _globals['_CALLACCEPTEDNOTIFICATION']._serialized_end=952
  _globals['_SUBSCRIBETOCALLDECLINEDNOTIFICATION']._serialized_start=954
  _globals['_SUBSCRIBETOCALLDECLINEDNOTIFICATION']._serialized_end=1028
  _globals['_CALLDECLINEDNOTIFICATION']._serialized_start=1031
  _globals['_CALLDECLINEDNOTIFICATION']._serialized_end=1183
  _globals['_SUBSCRIBETOCALLBUSYNOTIFICATION']._serialized_start=1185
  _globals['_SUBSCRIBETOCALLBUSYNOTIFICATION']._serialized_end=1255
  _globals['_CALLBUSYNOTIFICATION']._serialized_start=1258
  _globals['_CALLBUSYNOTIFICATION']._serialized_end=1406
  _globals['_SUBSCRIBETOCALLENDEDNOTIFICATION']._serialized_start=1408
  _globals['_SUBSCRIBETOCALLENDEDNOTIFICATION']._serialized_end=1479
  _globals['_CALLENDEDNOTIFICATION']._serialized_start=1481
  _globals['_CALLENDEDNOTIFICATION']._serialized_end=1545
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/keycloak_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/keycloak_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import identity_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_identity__pb2
from .....olvid.daemon.datatypes.v1 import keycloak_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_keycloak__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/olvid/daemon/command/v1/keycloak_commands.proto\x12\x17olvid.daemon.command.v1\x1a(olvid/daemon/datatypes/v1/identity.proto\x1a(olvid/daemon/datatypes/v1/keycloak.proto\"L\n\x1bKeycloakBindIdentityRequest\x12-\n\x12\x63onfiguration_link\x18\x01 \x01(\tR\x11\x63onfigurationLink\"\x1e\n\x1cKeycloakBindIdentityResponse\"\x1f\n\x1dKeycloakUnbindIdentityRequest\" \n\x1eKeycloakUnbindIdentityResponse\"\xbd\x01\n\x17KeycloakUserListRequest\x12J\n\x06\x66ilter\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.KeycloakUserFilterH\x00R\x06\x66ilter\x88\x01\x01\x12\x33\n\x13last_list_timestamp\x18\x02 \x01(\x04H\x01R\x11lastListTimestamp\x88\x01\x01\x42\t\n\x07_filterB\x16\n\x14_last_list_timestamp\"\x89\x01\n\x18KeycloakUserListResponse\x12=\n\x05users\x18\x01 \x03(\x0b\x32\'.olvid.daemon.datatypes.v1.KeycloakUserR\x05users\x12.\n\x13last_list_timestamp\x18\x02 \x01(\x04R\x11lastListTimestamp\"B\n\x1fKeycloakAddUserAsContactRequest\x12\x1f\n\x0bkeycloak_id\x18\x01 \x01(\tR\nkeycloakId\"\"\n KeycloakAddUserAsContactResponse\"\"\n KeycloakGetApiCredentialsRequest\"x\n!KeycloakGetApiCredentialsResponse\x12S\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.KeycloakApiCredentialsR\x0b\x63redentialsB\xc4\x01\n\x1b\x63om.olvid.daemon.command.v1B\x15KeycloakCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.keycloak_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\025KeycloakCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_KEYCLOAKBINDIDENTITYREQUEST']._serialized_start=160
  _globals['_KEYCLOAKBINDIDENTITYREQUEST']._serialized_end=236
  _globals['_KEYCLOAKBINDIDENTITYRESPONSE']._serialized_start=238
  _globals['_KEYCLOAKBINDIDENTITYRESPONSE']._serialized_end=268
  _globals['_KEYCLOAKUNBINDIDENTITYREQUEST']._serialized_start=270
  _globals['_KEYCLOAKUNBINDIDENTITYREQUEST']._serialized_end=301
  _globals['_KEYCLOAKUNBINDIDENTITYRESPONSE']._serialized_start=303
  _globals['_KEYCLOAKUNBINDIDENTITYRESPONSE']._serialized_end=335
  _globals['_KEYCLOAKUSERLISTREQUEST']._serialized_start=338
  _globals['_KEYCLOAKUSERLISTREQUEST']._serialized_end=527
  _globals['_KEYCLOAKUSERLISTRESPONSE']._serialized_start=530
  _globals['_KEYCLOAKUSERLISTRESPONSE']._serialized_end=667
  _globals['_KEYCLOAKADDUSERASCONTACTREQUEST']._serialized_start=669
  _globals['_KEYCLOAKADDUSERASCONTACTREQUEST']._serialized_end=735
  _globals['_KEYCLOAKADDUSERASCONTACTRESPONSE']._serialized_start=737
  _globals['_KEYCLOAKADDUSERASCONTACTRESPONSE']._serialized_end=771
  _globals['_KEYCLOAKGETAPICREDENTIALSREQUEST']._serialized_start=773
  _globals['_KEYCLOAKGETAPICREDENTIALSREQUEST']._serialized_end=807
  _globals['_KEYCLOAKGETAPICREDENTIALSRESPONSE']._serialized_start=809
  _globals['_KEYCLOAKGETAPICREDENTIALSRESPONSE']._serialized_end=929
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/message_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/message_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import message_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8olvid/daemon/notification/v1/message_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a\'olvid/daemon/datatypes/v1/message.proto\"\x9f\x01\n&SubscribeToMessageReceivedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"[\n\x1bMessageReceivedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\x9b\x01\n\"SubscribeToMessageSentNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"W\n\x17MessageSentNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xe5\x01\n%SubscribeToMessageDeletedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"Z\n\x1aMessageDeletedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xe9\x01\n)SubscribeToMessageBodyUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"\x83\x01\n\x1eMessageBodyUpdatedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12#\n\rprevious_body\x18\x02 \x01(\tR\x0cpreviousBody\"\xe6\x01\n&SubscribeToMessageUploadedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"[\n\x1bMessageUploadedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xe7\x01\n\'SubscribeToMessageDeliveredNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"\\\n\x1cMessageDeliveredNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xe2\x01\n\"SubscribeToMessageReadNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"W\n\x17MessageReadNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xa7\x01\n.SubscribeToMessageLocationReceivedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"c\n#MessageLocationReceivedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xa3\x01\n*SubscribeToMessageLocationSentNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"_\n\x1fMessageLocationSentNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xab\x01\n2SubscribeToMessageLocationSharingStartNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"g\n\'MessageLocationSharingStartNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xf3\x01\n3SubscribeToMessageLocationSharingUpdateNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"\xc1\x01\n(MessageLocationSharingUpdateNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12W\n\x11previous_location\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageLocationR\x10previousLocation\"\xf0\x01\n0SubscribeToMessageLocationSharingEndNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"e\n%MessageLocationSharingEndNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xd8\x02\n+SubscribeToMessageReactionAddedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x12W\n\x0freaction_filter\x18\x04 \x01(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterH\x02R\x0ereactionFilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filterB\x12\n\x10_reaction_filter\"\xa8\x01\n MessageReactionAddedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12\x46\n\x08reaction\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\x08reaction\"\xf8\x03\n-SubscribeToMessageReactionUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12T\n\x0emessage_filter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\rmessageFilter\x88\x01\x01\x12W\n\x0freaction_filter\x18\x04 \x01(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterH\x02R\x0ereactionFilter\x88\x01\x01\x12h\n\x18previous_reaction_filter\x18\x05 \x01(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterH\x03R\x16previousReactionFilter\x88\x01\x01\x42\x08\n\x06_countB\x11\n\x0f_message_filterB\x12\n\x10_reaction_filterB\x1b\n\x19_previous_reaction_filter\"\x83\x02\n\"MessageReactionUpdatedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12\x46\n\x08reaction\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\x08reaction\x12W\n\x11previous_reaction\x18\x03 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\x10previousReaction\"\xda\x02\n-SubscribeToMessageReactionRemovedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x0bmessage_ids\x18\x02 \x03(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\nmessageIds\x12\x45\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x01R\x06\x66ilter\x88\x01\x01\x12W\n\x0freaction_filter\x18\x04 \x01(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterH\x02R\x0ereactionFilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filterB\x12\n\x10_reaction_filter\"\xaa\x01\n\"MessageReactionRemovedNotification\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12\x46\n\x08reaction\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\x08reactionB\xe1\x01\n com.olvid.daemon.notification.v1B\x19MessageNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.message_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\031MessageNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOMESSAGERECEIVEDNOTIFICATION']._serialized_start=132
  _globals['_SUBSCRIBETOMESSAGERECEIVEDNOTIFICATION']._serialized_end=291
  _globals['_MESSAGERECEIVEDNOTIFICATION']._serialized_start=293
  _globals['_MESSAGERECEIVEDNOTIFICATION']._serialized_end=384
  _globals['_SUBSCRIBETOMESSAGESENTNOTIFICATION']._serialized_start=387
  _globals['_SUBSCRIBETOMESSAGESENTNOTIFICATION']._serialized_end=542
  _globals['_MESSAGESENTNOTIFICATION']._serialized_start=544
  _globals['_MESSAGESENTNOTIFICATION']._serialized_end=631
  _globals['_SUBSCRIBETOMESSAGEDELETEDNOTIFICATION']._serialized_start=634
  _globals['_SUBSCRIBETOMESSAGEDELETEDNOTIFICATION']._serialized_end=863
  _globals['_MESSAGEDELETEDNOTIFICATION']._serialized_start=865
  _globals['_MESSAGEDELETEDNOTIFICATION']._serialized_end=955
  _globals['_SUBSCRIBETOMESSAGEBODYUPDATEDNOTIFICATION']._serialized_start=958
  _globals['_SUBSCRIBETOMESSAGEBODYUPDATEDNOTIFICATION']._serialized_end=1191
  _globals['_MESSAGEBODYUPDATEDNOTIFICATION']._serialized_start=1194
  _globals['_MESSAGEBODYUPDATEDNOTIFICATION']._serialized_end=1325
  _globals['_SUBSCRIBETOMESSAGEUPLOADEDNOTIFICATION']._serialized_start=1328
  _globals['_SUBSCRIBETOMESSAGEUPLOADEDNOTIFICATION']._serialized_end=1558
  _globals['_MESSAGEUPLOADEDNOTIFICATION']._serialized_start=1560
  _globals['_MESSAGEUPLOADEDNOTIFICATION']._serialized_end=1651
  _globals['_SUBSCRIBETOMESSAGEDELIVEREDNOTIFICATION']._serialized_start=1654
  _globals['_SUBSCRIBETOMESSAGEDELIVEREDNOTIFICATION']._serialized_end=1885
  _globals['_MESSAGEDELIVEREDNOTIFICATION']._serialized_start=1887
  _globals['_MESSAGEDELIVEREDNOTIFICATION']._serialized_end=1979
  _globals['_SUBSCRIBETOMESSAGEREADNOTIFICATION']._serialized_start=1982
  _globals['_SUBSCRIBETOMESSAGEREADNOTIFICATION']._serialized_end=2208
  _globals['_MESSAGEREADNOTIFICATION']._serialized_start=2210
  _globals['_MESSAGEREADNOTIFICATION']._serialized_end=2297
  _globals['_SUBSCRIBETOMESSAGELOCATIONRECEIVEDNOTIFICATION']._serialized_start=2300
  _globals['_SUBSCRIBETOMESSAGELOCATIONRECEIVEDNOTIFICATION']._serialized_end=2467
  _globals['_MESSAGELOCATIONRECEIVEDNOTIFICATION']._serialized_start=2469
  _globals['_MESSAGELOCATIONRECEIVEDNOTIFICATION']._serialized_end=2568
  _globals['_SUBSCRIBETOMESSAGELOCATIONSENTNOTIFICATION']._serialized_start=2571
  _globals['_SUBSCRIBETOMESSAGELOCATIONSENTNOTIFICATION']._serialized_end=2734
  _globals['_MESSAGELOCATIONSENTNOTIFICATION']._serialized_start=2736
  _globals['_MESSAGELOCATIONSENTNOTIFICATION']._serialized_end=2831
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGSTARTNOTIFICATION']._serialized_start=2834
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGSTARTNOTIFICATION']._serialized_end=3005
  _globals['_MESSAGELOCATIONSHARINGSTARTNOTIFICATION']._serialized_start=3007
  _globals['_MESSAGELOCATIONSHARINGSTARTNOTIFICATION']._serialized_end=3110
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGUPDATENOTIFICATION']._serialized_start=3113
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGUPDATENOTIFICATION']._serialized_end=3356
  _globals['_MESSAGELOCATIONSHARINGUPDATENOTIFICATION']._serialized_start=3359
  _globals['_MESSAGELOCATIONSHARINGUPDATENOTIFICATION']._serialized_end=3552
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGENDNOTIFICATION']._serialized_start=3555
  _globals['_SUBSCRIBETOMESSAGELOCATIONSHARINGENDNOTIFICATION']._serialized_end=3795
  _globals['_MESSAGELOCATIONSHARINGENDNOTIFICATION']._serialized_start=3797
  _globals['_MESSAGELOCATIONSHARINGENDNOTIFICATION']._serialized_end=3898
  _globals['_SUBSCRIBETOMESSAGEREACTIONADDEDNOTIFICATION']._serialized_start=3901
  _globals['_SUBSCRIBETOMESSAGEREACTIONADDEDNOTIFICATION']._serialized_end=4245
  _globals['_MESSAGEREACTIONADDEDNOTIFICATION']._serialized_start=4248
  _globals['_MESSAGEREACTIONADDEDNOTIFICATION']._serialized_end=4416
  _globals['_SUBSCRIBETOMESSAGEREACTIONUPDATEDNOTIFICATION']._serialized_start=4419
  _globals['_SUBSCRIBETOMESSAGEREACTIONUPDATEDNOTIFICATION']._serialized_end=4923
  _globals['_MESSAGEREACTIONUPDATEDNOTIFICATION']._serialized_start=4926
  _globals['_MESSAGEREACTIONUPDATEDNOTIFICATION']._serialized_end=5185
  _globals['_SUBSCRIBETOMESSAGEREACTIONREMOVEDNOTIFICATION']._serialized_start=5188
  _globals['_SUBSCRIBETOMESSAGEREACTIONREMOVEDNOTIFICATION']._serialized_end=5534
  _globals['_MESSAGEREACTIONREMOVEDNOTIFICATION']._serialized_start=5537
  _globals['_MESSAGEREACTIONREMOVEDNOTIFICATION']._serialized_end=5707
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/backup.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/datatypes/v1/backup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import settings_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&olvid/daemon/datatypes/v1/backup.proto\x12\x19olvid.daemon.datatypes.v1\x1a(olvid/daemon/datatypes/v1/settings.proto\"\x90\x07\n\x06\x42\x61\x63kup\x12P\n\x0c\x61\x64min_backup\x18\x01 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.Backup.AdminBackupR\x0b\x61\x64minBackup\x12X\n\x0fprofile_backups\x18\x02 \x03(\x0b\x32/.olvid.daemon.datatypes.v1.Backup.ProfileBackupR\x0eprofileBackups\x1ax\n\x0b\x41\x64minBackup\x12\x33\n\x16\x61\x64min_client_key_count\x18\x01 \x01(\x04R\x13\x61\x64minClientKeyCount\x12\x34\n\x16storage_elements_count\x18\x02 \x01(\x04R\x14storageElementsCount\x1a\xdf\x04\n\rProfileBackup\x12\x30\n\x14profile_display_name\x18\x01 \x01(\tR\x12profileDisplayName\x12\x34\n\x16\x61lready_exists_locally\x18\x02 \x01(\x08R\x14\x61lreadyExistsLocally\x12)\n\x10keycloak_managed\x18\x03 \x01(\x08R\x0fkeycloakManaged\x12V\n\tsnapshots\x18\x04 \x03(\x0b\x32\x38.olvid.daemon.datatypes.v1.Backup.ProfileBackup.SnapshotR\tsnapshots\x1a\xe2\x02\n\x08Snapshot\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12(\n\x10\x66rom_device_name\x18\x03 \x01(\tR\x0e\x66romDeviceName\x12#\n\rcontact_count\x18\x04 \x01(\x04R\x0c\x63ontactCount\x12\x1f\n\x0bgroup_count\x18\x05 \x01(\x04R\ngroupCount\x12(\n\x10\x63lient_key_count\x18\x06 \x01(\x04R\x0e\x63lientKeyCount\x12\x34\n\x16storage_elements_count\x18\x07 \x01(\x04R\x14storageElementsCount\x12X\n\x11identity_settings\x18\x08 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.IdentitySettingsR\x10identitySettingsB\xc4\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\x0b\x42\x61\x63kupProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.backup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\013BackupProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_BACKUP']._serialized_start=112
  _globals['_BACKUP']._serialized_end=1024
  _globals['_BACKUP_ADMINBACKUP']._serialized_start=294
  _globals['_BACKUP_ADMINBACKUP']._serialized_end=414
  _globals['_BACKUP_PROFILEBACKUP']._serialized_start=417
  _globals['_BACKUP_PROFILEBACKUP']._serialized_end=1024
  _globals['_BACKUP_PROFILEBACKUP_SNAPSHOT']._serialized_start=670
  _globals['_BACKUP_PROFILEBACKUP_SNAPSHOT']._serialized_end=1024
# @@protoc_insertion_point(module_scope)




import asyncclick as click

from ..listen import listen
from ..interactive_tree import interactive_tree
from ..tools.ClientSingleton import ClientSingleton
from ..tools.auto_invitation import auto_invite
from ..tools.cli_tools import print_error_message
from ..tools.click_wrappers import WrapperGroup


#####
# tools
#####
@interactive_tree.group("tools", short_help="advanced commands to debug and manage daemon", cls=WrapperGroup)
def tools_tree():
	pass


#####
# tools listen
#####
@tools_tree.command(name="listen", help="listen notifications received for a specific or every notifications")
@click.option("--filter", "filter_", type=str)
@click.option("--count", "-c", "count", type=int, default=0)
@click.option("-i", "--identity", "identity_id", default=-1, type=click.INT, help="Specify a specific identity to listen")
@click.option("-q", "--quiet", "quiet", is_flag=True, help="Hide notification content")
@click.option("-v", "--verbose", "verbose", is_flag=True, help="Show notification full content")
@click.option("-n", "--notifications", "notifications", type=str, help="Coma separated list of notifications to listen (upper snake case: MESSAGE_SEND,MESSAGE_RECEIVED)")
async def listen_cmd(identity_id: int = -1, verbose: bool = False, quiet: bool = False, notifications: str = "", filter_=None, count=0):
	if identity_id == -1:
		identity_id = ClientSingleton.get_current_identity_id()
	await listen(identity_id, verbose=verbose, quiet=quiet, notifications_to_listen=notifications, filter_=filter_, count=count)
	exit(0)


#####
# tools auto-invite
#####
@tools_tree.command(name="auto-invite", help="add every other identity on this daemon as a contact")
@click.option("-i", "--identity", "identity_id", default=-1, type=click.INT, help="Specify a specific identity to use")
@click.option("-f", "--full", "full", is_flag=True, help="Present every identity in the server to each other (else it only present current identity to others)")
async def auto_invite_cmd(full: bool, identity_id: int = -1):
	if identity_id == -1:
		identity_id = ClientSingleton.get_current_identity_id()
	if not full and identity_id <= 0:
		print_error_message("Specify identity to use or --full flag")
		return
	await auto_invite(identity_id, ClientSingleton.get_client(), full=full)


#####
# tools daemon-version
#####
@tools_tree.command(name="daemon-version", help="show daemon version")
async def auto_accept_cmd():
	print(await ClientSingleton.get_client().daemon_version())



# import core clients
# noinspection PyUnusedImports
from .core import OlvidClient
# noinspection PyUnusedImports
from .core import OlvidAdminClient
# noinspection PyUnusedImports
from .core import errors

# import core elements
# noinspection PyUnusedImports
from . import listeners

# import overlay modules
# noinspection PyUnusedImports
from . import datatypes
# noinspection PyUnusedImports
from . import internal

# import bots
# noinspection PyUnusedImports
from . import tools

# delete imported modules
if "core" in locals() or "core" in globals():
	del core

if "protobuf" in locals() or "protobuf" in globals():
	# noinspection PyUnresolvedReferences
	del protobuf

# noinspection PyUnusedImports
from .version import __version__
# noinspection PyUnusedImports
from .version import __docker_version__
del version



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/message.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/datatypes/v1/message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'olvid/daemon/datatypes/v1/message.proto\x12\x19olvid.daemon.datatypes.v1\"\x9d\x01\n\tMessageId\x12=\n\x04type\x18\x01 \x01(\x0e\x32).olvid.daemon.datatypes.v1.MessageId.TypeR\x04type\x12\x0e\n\x02id\x18\x02 \x01(\x04R\x02id\"A\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cTYPE_INBOUND\x10\x01\x12\x11\n\rTYPE_OUTBOUND\x10\x02\"\xe9\x04\n\x07Message\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\x02id\x12#\n\rdiscussion_id\x18\x02 \x01(\x04R\x0c\x64iscussionId\x12\x1b\n\tsender_id\x18\x03 \x01(\x04R\x08senderId\x12\x12\n\x04\x62ody\x18\x04 \x01(\tR\x04\x62ody\x12\x1d\n\nsort_index\x18\x05 \x01(\x01R\tsortIndex\x12\x1c\n\ttimestamp\x18\x06 \x01(\x04R\ttimestamp\x12+\n\x11\x61ttachments_count\x18\x07 \x01(\x04R\x10\x61ttachmentsCount\x12W\n\x12replied_message_id\x18\x08 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdH\x00R\x10repliedMessageId\x88\x01\x01\x12Z\n\x10message_location\x18\n \x01(\x0b\x32*.olvid.daemon.datatypes.v1.MessageLocationH\x01R\x0fmessageLocation\x88\x01\x01\x12H\n\treactions\x18\x0b \x03(\x0b\x32*.olvid.daemon.datatypes.v1.MessageReactionR\treactions\x12\x1c\n\tforwarded\x18\x0c \x01(\x08R\tforwarded\x12\x1f\n\x0b\x65\x64ited_body\x18\r \x01(\x08R\neditedBodyB\x15\n\x13_replied_message_idB\x13\n\x11_message_location\"\x92\x01\n\x13MessageEphemerality\x12\x1b\n\tread_once\x18\x01 \x01(\x08R\x08readOnce\x12-\n\x12\x65xistence_duration\x18\x02 \x01(\x04R\x11\x65xistenceDuration\x12/\n\x13visibility_duration\x18\x03 \x01(\x04R\x12visibilityDuration\"j\n\x0fMessageReaction\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\x12\x1a\n\x08reaction\x18\x02 \x01(\tR\x08reaction\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp\"\xc7\x03\n\x0fMessageLocation\x12K\n\x04type\x18\x01 \x01(\x0e\x32\x37.olvid.daemon.datatypes.v1.MessageLocation.LocationTypeR\x04type\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12\x1a\n\x08latitude\x18\x03 \x01(\x01R\x08latitude\x12\x1c\n\tlongitude\x18\x04 \x01(\x01R\tlongitude\x12\x1f\n\x08\x61ltitude\x18\x05 \x01(\x01H\x00R\x08\x61ltitude\x88\x01\x01\x12!\n\tprecision\x18\x06 \x01(\x02H\x01R\tprecision\x88\x01\x01\x12\x1d\n\x07\x61\x64\x64ress\x18\x07 \x01(\tH\x02R\x07\x61\x64\x64ress\x88\x01\x01\"\x84\x01\n\x0cLocationType\x12\x1d\n\x19LOCATION_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12LOCATION_TYPE_SEND\x10\x01\x12\x19\n\x15LOCATION_TYPE_SHARING\x10\x02\x12\"\n\x1eLOCATION_TYPE_SHARING_FINISHED\x10\x03\x42\x0b\n\t_altitudeB\x0c\n\n_precisionB\n\n\x08_address\"\xaa\n\n\rMessageFilter\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32).olvid.daemon.datatypes.v1.MessageId.TypeH\x01R\x04type\x88\x01\x01\x12(\n\rdiscussion_id\x18\x02 \x01(\x04H\x02R\x0c\x64iscussionId\x88\x01\x01\x12/\n\x11sender_contact_id\x18\x03 \x01(\x04H\x03R\x0fsenderContactId\x88\x01\x01\x12$\n\x0b\x62ody_search\x18\x05 \x01(\tH\x04R\nbodySearch\x88\x01\x01\x12X\n\nattachment\x18\x06 \x01(\x0e\x32\x33.olvid.daemon.datatypes.v1.MessageFilter.AttachmentH\x05R\nattachment\x88\x01\x01\x12R\n\x08location\x18\x07 \x01(\x0e\x32\x31.olvid.daemon.datatypes.v1.MessageFilter.LocationH\x06R\x08location\x88\x01\x01\x12(\n\rmin_timestamp\x18\x08 \x01(\x04H\x07R\x0cminTimestamp\x88\x01\x01\x12(\n\rmax_timestamp\x18\t \x01(\x04H\x08R\x0cmaxTimestamp\x88\x01\x01\x12Y\n\x0chas_reaction\x18\n \x01(\x0e\x32\x31.olvid.daemon.datatypes.v1.MessageFilter.ReactionH\tR\x0bhasReaction\x88\x01\x01\x12T\n\x10reactions_filter\x18\x0b \x03(\x0b\x32).olvid.daemon.datatypes.v1.ReactionFilterR\x0freactionsFilter\x12-\n\x12reply_to_a_message\x18\r \x01(\x08H\x00R\x0freplyToAMessage\x12\x39\n\x19\x64o_not_reply_to_a_message\x18\x0e \x01(\x08H\x00R\x14\x64oNotReplyToAMessage\x12T\n\x12replied_message_id\x18\x0f \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdH\x00R\x10repliedMessageId\"V\n\nAttachment\x12\x1a\n\x16\x41TTACHMENT_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x41TTACHMENT_HAVE\x10\x01\x12\x17\n\x13\x41TTACHMENT_HAVE_NOT\x10\x02\"\x9f\x01\n\x08Location\x12\x18\n\x14LOCATION_UNSPECIFIED\x10\x00\x12\x11\n\rLOCATION_HAVE\x10\x01\x12\x15\n\x11LOCATION_HAVE_NOT\x10\x02\x12\x14\n\x10LOCATION_IS_SEND\x10\x03\x12\x17\n\x13LOCATION_IS_SHARING\x10\x05\x12 \n\x1cLOCATION_IS_SHARING_FINISHED\x10\x06\"L\n\x08Reaction\x12\x18\n\x14REACTION_UNSPECIFIED\x10\x00\x12\x10\n\x0cREACTION_HAS\x10\x01\x12\x14\n\x10REACTION_HAS_NOT\x10\x02\x42\x07\n\x05replyB\x07\n\x05_typeB\x10\n\x0e_discussion_idB\x14\n\x12_sender_contact_idB\x0e\n\x0c_body_searchB\r\n\x0b_attachmentB\x0b\n\t_locationB\x10\n\x0e_min_timestampB\x10\n\x0e_max_timestampB\x0f\n\r_has_reaction\"\xa7\x01\n\x0eReactionFilter\x12$\n\rreacted_by_me\x18\n \x01(\x08H\x00R\x0breactedByMe\x12\x33\n\x15reacted_by_contact_id\x18\x0b \x01(\x04H\x00R\x12reactedByContactId\x12\x1f\n\x08reaction\x18\x0c \x01(\tH\x01R\x08reaction\x88\x01\x01\x42\x0c\n\nreacted_byB\x0b\n\t_reactionB\xc5\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\x0cMessageProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\014MessageProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_MESSAGEID']._serialized_start=71
  _globals['_MESSAGEID']._serialized_end=228
  _globals['_MESSAGEID_TYPE']._serialized_start=163
  _globals['_MESSAGEID_TYPE']._serialized_end=228
  _globals['_MESSAGE']._serialized_start=231
  _globals['_MESSAGE']._serialized_end=848
  _globals['_MESSAGEEPHEMERALITY']._serialized_start=851
  _globals['_MESSAGEEPHEMERALITY']._serialized_end=997
  _globals['_MESSAGEREACTION']._serialized_start=999
  _globals['_MESSAGEREACTION']._serialized_end=1105
  _globals['_MESSAGELOCATION']._serialized_start=1108
  _globals['_MESSAGELOCATION']._serialized_end=1563
  _globals['_MESSAGELOCATION_LOCATIONTYPE']._serialized_start=1392
  _globals['_MESSAGELOCATION_LOCATIONTYPE']._serialized_end=1524
  _globals['_MESSAGEFILTER']._serialized_start=1566
  _globals['_MESSAGEFILTER']._serialized_end=2888
  _globals['_MESSAGEFILTER_ATTACHMENT']._serialized_start=2407
  _globals['_MESSAGEFILTER_ATTACHMENT']._serialized_end=2493
  _globals['_MESSAGEFILTER_LOCATION']._serialized_start=2496
  _globals['_MESSAGEFILTER_LOCATION']._serialized_end=2655
  _globals['_MESSAGEFILTER_REACTION']._serialized_start=2657
  _globals['_MESSAGEFILTER_REACTION']._serialized_end=2733
  _globals['_REACTIONFILTER']._serialized_start=2891
  _globals['_REACTIONFILTER']._serialized_end=3058
# @@protoc_insertion_point(module_scope)



import asyncio
import datetime
import logging
import uuid
from asyncio import InvalidStateError

from ClientHolder import ClientHolder, ClientWrapper
from olvid import datatypes, OlvidClient, listeners
from utils.tools_message import send_message_wait_and_check_content
from utils.tools_group import create_standard_group


async def test_message_retention_duration(client_1: ClientWrapper, client_2: ClientWrapper):
	original_settings: datatypes.IdentitySettings = await client_1.settings_identity_get()
	try:
		# populate discussions with "old messages" (messages to delete)
		tasks = []
		random_body: str = str(uuid.uuid4())[:4]
		for i in range(1, 10):
			tasks.append(send_message_wait_and_check_content(client_1, client_2, f"settings - {i} - {random_body}"))
		for task in tasks:
			await task

		# determine limit timestamp
		limit_timestamp: int = [m async for m in client_1.message_list()][-1].timestamp

		# wait before next population
		logging.info(f"sleep before sending messages")
		await asyncio.sleep(5)

		# populate discussions with "new messages" (messages to keep)
		tasks = []
		random_body: str = str(uuid.uuid4())[:4]
		for i in range(1, 10):
			tasks.append(send_message_wait_and_check_content(client_1, client_2, f"settings - {i} - {random_body}"))
		for task in tasks:
			await task

		# determine messages to delete and messages to keep
		all_messages: list[datatypes.Message] = [m async for m in client_1.message_list()]
		messages_to_delete: list[datatypes.Message] = [m for m in all_messages if m.timestamp <= limit_timestamp]
		messages_to_keep: list[datatypes.Message] = [m for m in all_messages if m.timestamp > limit_timestamp]

		# create listener for message deleting
		# create one bot for each message
		bots: list[OlvidClient] = [client_1.create_notification_bot(listener=listeners.MessageDeletedListener(handler=lambda m: m, count=1, message_ids=[m.id])) for m in messages_to_delete]
		# create a bot for all messages to let watchdog know we listen
		bots.append(client_1.create_notification_bot(listener=listeners.MessageDeletedListener(handler=lambda m: m, count=len(messages_to_delete))))

		# change settings
		new_settings: datatypes.IdentitySettings = original_settings._clone()
		new_settings.message_retention.existence_duration = round(datetime.datetime.now().timestamp() - (limit_timestamp/1000)) - 1
		await client_1.settings_identity_set(identity_settings=new_settings)

		# wait for message deletion
		for bot in bots:
			await bot.wait_for_listeners_end()

		# check we deleted messages correctly
		kept_messages: list[datatypes.Message] = [m async for m in client_1.message_list()]
		if len(kept_messages) != len(messages_to_keep):
			raise ValueError("Deleted too many messages")
		for i in range(len(kept_messages)):
			if not kept_messages[i].id.__eq__(messages_to_keep[i].id):
				raise ValueError("Wrong messages kept")
	finally:
		# restore settings
		await client_1.settings_identity_set(identity_settings=original_settings)


async def test_message_retention_discussion_count(client_1: ClientWrapper, client_2: ClientWrapper):
	original_settings: datatypes.IdentitySettings = await client_1.settings_identity_get()
	try:
		# populate discussions
		tasks = []
		random_body: str = str(uuid.uuid4())[:4]
		for i in range(1, 10):
			tasks.append(send_message_wait_and_check_content(client_1, client_2, f"settings - {i} - {random_body}"))
		for task in tasks:
			await task

		# get current messages
		all_messages: list[datatypes.Message] = [m async for m in client_1.message_list()]
		messages_by_discussion: dict[int, list[datatypes.Message]] = {}
		for m in all_messages:
			if not messages_by_discussion.get(m.discussion_id):
				messages_by_discussion[m.discussion_id] = []
			messages_by_discussion[m.discussion_id].append(m)

		# determine messages to delete and messages to keep
		messages_to_delete: list[datatypes.Message] = []
		messages_to_keep: list[datatypes.Message] = []
		for did in messages_by_discussion.keys():
			if len(messages_by_discussion[did]) > 8:
				messages_to_delete.extend(messages_by_discussion[did][:-8])
				messages_to_keep.extend(messages_by_discussion[did][-8:])
			else:
				messages_to_keep.extend(messages_by_discussion[did])

		# create listener for message deleting
		# create one bot for each message
		bots: list[OlvidClient] = [client_1.create_notification_bot(listener=listeners.MessageDeletedListener(handler=lambda m: m, count=1, message_ids=[m.id])) for m in messages_to_delete]
		# create a bot for all messages to let watchdog know we listen
		bots.append(client_1.create_notification_bot(listener=listeners.MessageDeletedListener(handler=lambda m: m, count=len(messages_to_delete))))

		# change settings
		new_settings: datatypes.IdentitySettings = original_settings._clone()
		new_settings.message_retention.discussion_count = 8
		await client_1.settings_identity_set(identity_settings=new_settings)

		# wait for message deletion
		for bot in bots:
			await bot.wait_for_listeners_end()

		# check we do not deleted messages in other discussions
		all_messages_refreshed: list[datatypes.Message] = [m async for m in client_1.message_list()]
		if len(all_messages) != len(all_messages_refreshed) + len(messages_to_delete):
			raise ValueError("Deleted messages in other discussions")
	finally:
		# restore settings
		await client_1.settings_identity_set(identity_settings=original_settings)


async def test_message_retention_global_count(client_1: ClientWrapper, client_2: ClientWrapper):
	original_settings: datatypes.IdentitySettings = await client_1.settings_identity_get()
	try:
		# populate discussions
		tasks = []
		random_body: str = str(uuid.uuid4())[:4]
		for i in range(1, 10):
			tasks.append(send_message_wait_and_check_content(client_1, client_2, f"settings - {i} - {random_body}"))
		for task in tasks:
			await task

		# get current messages
		all_messages: list[datatypes.Message] = [m async for m in client_1.message_list()]
		if len(all_messages) < 10:
			raise InvalidStateError("Do not found enough messages")

		# determine messages to delete and messages to keep
		messages_to_delete: list[datatypes.Message] = all_messages[:-9]
		messages_to_keep: list[datatypes.Message] = all_messages[-9:]

		# create listener for message deleting
		# create one bot for each message
		bots: list[OlvidClient] = [client_1.create_notification_bot(listener=listeners.MessageDeletedListener(handler=lambda m: m, count=1, message_ids=[m.id])) for m in messages_to_delete]
		# create a bot for all messages to let watchdog know we listen
		bots.append(client_1.create_notification_bot(listener=listeners.MessageDeletedListener(handler=lambda m: m, count=len(messages_to_delete))))

		# change settings
		new_settings: datatypes.IdentitySettings = original_settings._clone()
		new_settings.message_retention.global_count = 9
		await client_1.settings_identity_set(identity_settings=new_settings)

		# wait for message deletion
		for bot in bots:
			await bot.wait_for_listeners_end()

		# check we do not deleted more messages than expected in discussion
		kept_messages: list[datatypes.Message] = [m async for m in client_1.message_list()]
		if len(kept_messages) != len(messages_to_keep):
			raise ValueError("Deleted too many messages")
		for i in range(len(kept_messages)):
			if not kept_messages[i].id.__eq__(messages_to_keep[i].id):
				raise ValueError("Wrong messages kept")
	finally:
		# restore settings
		await client_1.settings_identity_set(identity_settings=original_settings)


async def test_message_retention_locked(client_holder: ClientHolder, client_1: ClientWrapper):
	original_identity_settings: datatypes.IdentitySettings = await client_1.settings_identity_get()
	try:
		# create a group and post messages
		group_1: datatypes.Group = await create_standard_group(client_holder=client_holder, admin_client=client_1, group_name="Locked Group", group_description="")
		group_discussion_1: datatypes.Discussion = await client_1.discussion_get_by_group(group_id=group_1.id)
		bots: list[OlvidClient] = [
			client_1.create_notification_bot(listener=listeners.MessageSentListener(handler=lambda i: i, count=5)),
			client_1.create_notification_bot(listener=listeners.MessageUploadedListener(handler=lambda i: i, count=5)),
			client_1.create_notification_bot(listener=listeners.MessageDeliveredListener(handler=lambda i: i, count=5)),
			client_1.create_notification_bot(listener=listeners.MessageReadListener(handler=lambda i: i, count=5)),
		]
		for c in client_holder.clients[1:]:
			bots.append(c.create_notification_bot(listener=listeners.MessageReceivedListener(handler=lambda i: i, count=5)))
		for i in range(5):
			await group_discussion_1.post_message(client_1, f"locked message - {i}")
		for bot in bots:
			await bot.wait_for_listeners_end()

		# get messages
		locked_discussion_ids: list[int] = [d.id async for d in client_1.discussion_locked_list()]
		all_messages: list[datatypes.Message] = [m async for m in client_1.message_list()]
		messages_to_keep: list[datatypes.Message] = [m for m in all_messages if m.discussion_id not in locked_discussion_ids]

		# prepare listeners for group disband
		bots: list[OlvidClient] = [
			client_1.create_notification_bot(listener=listeners.GroupDeletedListener(handler=lambda i: i, count=1)),
			client_1.create_notification_bot(listener=listeners.DiscussionLockedListener(handler=lambda i: i, count=1)),
		]
		for c in client_holder.clients[1:]:
			bots.append(c.create_notification_bot(listener=listeners.GroupDeletedListener(handler=lambda i: i, count=1)))
			bots.append(c.create_notification_bot(listener=listeners.DiscussionLockedListener(handler=lambda i: i, count=1)))

		# disband group
		await group_1.disband(client_1)
		for bot in bots:
			await bot.wait_for_listeners_end()

		# change settings
		new_settings: datatypes.IdentitySettings = original_identity_settings._clone()
		new_settings.message_retention.clean_locked_discussions = True
		await client_1.settings_identity_set(identity_settings=new_settings)

		# check we do not deleted more messages than expected in discussion
		kept_messages: list[datatypes.Message] = [m async for m in client_1.message_list()]
		if len(kept_messages) != len(messages_to_keep):
			raise ValueError("Deleted too many messages")
		for i in range(len(kept_messages)):
			if not kept_messages[i].id.__eq__(messages_to_keep[i].id):
				raise ValueError("Wrong messages kept")
	finally:
		await client_1.settings_identity_set(identity_settings=original_identity_settings)


async def test_invitation_auto_accept_one_to_one(client_1: ClientWrapper, client_2: ClientWrapper):
	original_identity_settings: datatypes.IdentitySettings = await client_2.settings_identity_get()
	try:
		######
		# Auto accept pending invitations (when you change settings browse pending invitations and accept them if necessary)
		######
		contact_1_2 = await client_1.get_contact_associated_to_another_client(client_2)

		# downgrade one to one contact and re-invite him
		if contact_1_2.has_one_to_one_discussion:
			bots: list[OlvidClient] = [
				client_1.create_notification_bot(listener=listeners.DiscussionLockedListener(handler=lambda i: i, count=1)),
				client_2.create_notification_bot(listener=listeners.DiscussionLockedListener(handler=lambda i: i, count=1)),
			]
			await client_1.contact_downgrade_one_to_one_discussion(contact_id=contact_1_2.id)
			for bot in bots:
				await bot.wait_for_listeners_end()

		# add global listeners to let watchdog think we are listening
		bots: list[OlvidClient] = [
			client_1.create_notification_bot(listener=listeners.InvitationSentListener(handler=lambda i: i, count=1)),
			client_1.create_notification_bot(listener=listeners.InvitationDeletedListener(handler=lambda i: i, count=1)),
			client_1.create_notification_bot(listener=listeners.DiscussionNewListener(handler=lambda i: i, count=1)),
			client_2.create_notification_bot(listener=listeners.InvitationReceivedListener(handler=lambda i: i, count=1)),
			client_2.create_notification_bot(listener=listeners.InvitationDeletedListener(handler=lambda i: i, count=1)),
			client_2.create_notification_bot(listener=listeners.DiscussionNewListener(handler=lambda i: i, count=1)),
		]

		await client_1.contact_invite_to_one_to_one_discussion(contact_id=contact_1_2.id)
		# change settings and check pending invitation was accepted
		identity_settings: datatypes.IdentitySettings = original_identity_settings._clone()
		identity_settings.invitation.auto_accept_one_to_one = True
		await client_2.settings_identity_set(identity_settings=identity_settings)

		for bot in bots:
			await bot.wait_for_listeners_end()

		assert (await client_1.contact_get(contact_id=contact_1_2.id)).has_one_to_one_discussion, "one to one not restored (1)"

		######
		# Auto accept new invitations (when you change settings browse pending invitations and accept them if necessary)
		######
		# downgrade one to one
		bots: list[OlvidClient] = [
			client_1.create_notification_bot(listener=listeners.DiscussionLockedListener(handler=lambda i: i, count=1)),
			client_2.create_notification_bot(listener=listeners.DiscussionLockedListener(handler=lambda i: i, count=1)),
		]
		await client_1.contact_downgrade_one_to_one_discussion(contact_id=contact_1_2.id)
		for bot in bots:
			await bot.wait_for_listeners_end()

		# add global listeners to let watchdog think we are listening
		bots: list[OlvidClient] = [
			client_1.create_notification_bot(listener=listeners.InvitationSentListener(handler=lambda i: i, count=1)),
			client_1.create_notification_bot(listener=listeners.InvitationDeletedListener(handler=lambda i: i, count=1)),
			client_1.create_notification_bot(listener=listeners.DiscussionNewListener(handler=lambda i: i, count=1)),
			client_2.create_notification_bot(listener=listeners.InvitationReceivedListener(handler=lambda i: i, count=1)),
			client_2.create_notification_bot(listener=listeners.InvitationDeletedListener(handler=lambda i: i, count=1)),
			client_2.create_notification_bot(listener=listeners.DiscussionNewListener(handler=lambda i: i, count=1)),
		]

		await client_1.contact_invite_to_one_to_one_discussion(contact_id=contact_1_2.id)
		# change settings and check pending invitation was accepted
		identity_settings: datatypes.IdentitySettings = original_identity_settings._clone()
		identity_settings.invitation.auto_accept_one_to_one = True
		await client_2.settings_identity_set(identity_settings=identity_settings)

		for bot in bots:
			await bot.wait_for_listeners_end()

		assert (await client_1.contact_get(contact_id=contact_1_2.id)).has_one_to_one_discussion, "one to one not restored (2)"
	finally:
		await client_2.settings_identity_set(identity_settings=original_identity_settings)

async def test_cron_tasks(client_holder: ClientHolder, client_1: ClientWrapper):
	original_identity_settings: datatypes.IdentitySettings = await client_1.settings_identity_get()
	# a bot to ignore message deleted notifications
	messages_deleted_bot = client_1.create_notification_bot(listener=listeners.MessageDeletedListener(handler=lambda m: m))
	try:
		# prepare and set settings
		identity_settings = original_identity_settings._clone()
		identity_settings.message_retention.global_count = 9
		identity_settings.message_retention.discussion_count = 4
		await client_1.settings_identity_set(identity_settings=identity_settings)

		# wait for initial routine end daemon side
		await asyncio.sleep(1)

		# now populate with messages
		random_body: str = str(uuid.uuid4())[:4]
		for other_client in client_holder.clients[1:]:
			discussion: datatypes.Discussion = await client_1.get_discussion_associated_to_another_client(other_client)
			bots: list[OlvidClient] = [
				client_1.create_notification_bot(listener=listeners.MessageSentListener(handler=lambda i: i, count=5)),
				client_1.create_notification_bot(listener=listeners.MessageUploadedListener(handler=lambda i: i, count=5)),
				client_1.create_notification_bot(listener=listeners.MessageDeliveredListener(handler=lambda i: i, count=5)),
				client_1.create_notification_bot(listener=listeners.MessageReadListener(handler=lambda i: i, count=5)),
				other_client.create_notification_bot(listener=listeners.MessageReceivedListener(handler=lambda i: i, count=5)),
			]
			for i in range(5):
				await discussion.post_message(client_1, f"{i} - {discussion.id} - {random_body}")
			for bot in bots:
				await bot.wait_for_listeners_end()

		# determine a minimum number of messages to delete
		messages_to_delete_count: int = len([m async for m in client_1.message_list()]) - identity_settings.message_retention.global_count
		bots = [client_1.create_notification_bot(listener=listeners.MessageDeletedListener(handler=lambda m: m, count=messages_to_delete_count))]

		logging.info(f"Wait for next cron execution, expected around: {datetime.datetime.now() + datetime.timedelta(minutes=5)}")
		for bot in bots:
			await bot.wait_for_listeners_end()

		# check message cleaning respect expectations
		assert len([m async for m in client_1.message_list()]) <= identity_settings.message_retention.global_count, "global count incorrect"
		async for d in client_1.discussion_list():
			assert len([m async for m in client_1.message_list(filter=datatypes.MessageFilter(discussion_id=d.id))]) <= identity_settings.message_retention.discussion_count, f"discussion count incorrect: {d.id}"
	finally:
		await messages_deleted_bot.stop()
		await client_1.settings_identity_set(identity_settings=original_identity_settings)

async def test_settings(client_holder: ClientHolder, fast_mode: bool):
	c1, c2 = client_holder.get_one_client_pair()

	# reset settings
	for c in client_holder.clients:
		await c.settings_identity_set(identity_settings=datatypes.IdentitySettings())

	#####
	# Message retention
	#####
	if not fast_mode:
		logging.info(f"{c1.identity.id} <-> {c2.identity.id}: settings: message retention: duration")
		logging.info("(this test implies race conditions and might fail with bad network conditions)")
		await test_message_retention_duration(c1, c2)
	logging.info(f"{c1.identity.id} <-> {c2.identity.id}: settings: message retention: discussion count")
	await test_message_retention_discussion_count(c1, c2)
	logging.info(f"{c1.identity.id} <-> {c2.identity.id}: settings: message retention: global count")
	await test_message_retention_global_count(c1, c2)
	logging.info(f"{c1.identity.id} <-> {c2.identity.id}: settings: message retention: locked discussions")
	await test_message_retention_locked(client_holder, c1)
	if not fast_mode:
		logging.info(f"{c1.identity.id} <-> {c2.identity.id}: settings: message retention: cron tasks")
		await test_cron_tasks(client_holder, c1)

	#####
	# Invitation auto accept
	#####
	logging.info(f"{c1.identity.id} <-> {c2.identity.id}: settings: invitation auto accept: one to one")
	await test_invitation_auto_accept_one_to_one(c1, c2)

	#####
	# Keycloak auto invite
	#####
	# TODO



from .admin import BackupKeyGetRequest, BackupKeyGetResponse, BackupKeyRenewRequest, BackupKeyRenewResponse, BackupGetRequest, BackupGetResponse, BackupNowRequest, BackupNowResponse, BackupRestoreDaemonRequest, BackupRestoreDaemonResponse, BackupRestoreAdminBackupRequest, BackupRestoreAdminBackupResponse, BackupRestoreProfileSnapshotRequest, BackupRestoreProfileSnapshotResponse, ClientKeyListRequest, ClientKeyListResponse, ClientKeyGetRequest, ClientKeyGetResponse, ClientKeyNewRequest, ClientKeyNewResponse, ClientKeyDeleteRequest, ClientKeyDeleteResponse, IdentityListRequest, IdentityListResponse, IdentityAdminGetRequest, IdentityAdminGetResponse, IdentityAdminGetBytesIdentifierRequest, IdentityAdminGetBytesIdentifierResponse, IdentityAdminGetInvitationLinkRequest, IdentityAdminGetInvitationLinkResponse, IdentityAdminDownloadPhotoRequest, IdentityAdminDownloadPhotoResponse, IdentityNewRequest, IdentityNewResponse, IdentityKeycloakNewRequest, IdentityKeycloakNewResponse, IdentityDeleteRequest, IdentityDeleteResponse, ClientKeyAdminServiceStub, IdentityAdminServiceStub, BackupAdminServiceStub
del admin



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/attachment.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/datatypes/v1/attachment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import message_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*olvid/daemon/datatypes/v1/attachment.proto\x12\x19olvid.daemon.datatypes.v1\x1a\'olvid/daemon/datatypes/v1/message.proto\"\xa3\x01\n\x0c\x41ttachmentId\x12@\n\x04type\x18\x01 \x01(\x0e\x32,.olvid.daemon.datatypes.v1.AttachmentId.TypeR\x04type\x12\x0e\n\x02id\x18\x02 \x01(\x04R\x02id\"A\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cTYPE_INBOUND\x10\x01\x12\x11\n\rTYPE_OUTBOUND\x10\x02\"\xfd\x01\n\nAttachment\x12\x37\n\x02id\x18\x01 \x01(\x0b\x32\'.olvid.daemon.datatypes.v1.AttachmentIdR\x02id\x12#\n\rdiscussion_id\x18\x02 \x01(\x04R\x0c\x64iscussionId\x12\x43\n\nmessage_id\x18\x03 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\tmessageId\x12\x1b\n\tfile_name\x18\x04 \x01(\tR\x08\x66ileName\x12\x1b\n\tmime_type\x18\x05 \x01(\tR\x08mimeType\x12\x12\n\x04size\x18\x06 \x01(\x04R\x04size\"\xfb\x05\n\x10\x41ttachmentFilter\x12\x45\n\x04type\x18\x01 \x01(\x0e\x32,.olvid.daemon.datatypes.v1.AttachmentId.TypeH\x00R\x04type\x88\x01\x01\x12V\n\tfile_type\x18\x02 \x01(\x0e\x32\x34.olvid.daemon.datatypes.v1.AttachmentFilter.FileTypeH\x01R\x08\x66ileType\x88\x01\x01\x12(\n\rdiscussion_id\x18\x03 \x01(\x04H\x02R\x0c\x64iscussionId\x88\x01\x01\x12H\n\nmessage_id\x18\x05 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdH\x03R\tmessageId\x88\x01\x01\x12,\n\x0f\x66ilename_search\x18\x06 \x01(\tH\x04R\x0e\x66ilenameSearch\x88\x01\x01\x12-\n\x10mime_type_search\x18\x07 \x01(\tH\x05R\x0emimeTypeSearch\x88\x01\x01\x12\x1e\n\x08min_size\x18\x08 \x01(\x04H\x06R\x07minSize\x88\x01\x01\x12\x1e\n\x08max_size\x18\t \x01(\x04H\x07R\x07maxSize\x88\x01\x01\"\xbb\x01\n\x08\x46ileType\x12\x19\n\x15\x46ILE_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x46ILE_TYPE_IMAGE\x10\x03\x12\x13\n\x0f\x46ILE_TYPE_VIDEO\x10\x04\x12\x19\n\x15\x46ILE_TYPE_IMAGE_VIDEO\x10\x05\x12\x13\n\x0f\x46ILE_TYPE_AUDIO\x10\x06\x12\x1a\n\x16\x46ILE_TYPE_LINK_PREVIEW\x10\x07\x12\x1e\n\x1a\x46ILE_TYPE_NOT_LINK_PREVIEW\x10\x08\x42\x07\n\x05_typeB\x0c\n\n_file_typeB\x10\n\x0e_discussion_idB\r\n\x0b_message_idB\x12\n\x10_filename_searchB\x13\n\x11_mime_type_searchB\x0b\n\t_min_sizeB\x0b\n\t_max_sizeB\xc8\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\x0f\x41ttachmentProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.attachment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\017AttachmentProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_ATTACHMENTID']._serialized_start=115
  _globals['_ATTACHMENTID']._serialized_end=278
  _globals['_ATTACHMENTID_TYPE']._serialized_start=213
  _globals['_ATTACHMENTID_TYPE']._serialized_end=278
  _globals['_ATTACHMENT']._serialized_start=281
  _globals['_ATTACHMENT']._serialized_end=534
  _globals['_ATTACHMENTFILTER']._serialized_start=537
  _globals['_ATTACHMENTFILTER']._serialized_end=1300
  _globals['_ATTACHMENTFILTER_FILETYPE']._serialized_start=990
  _globals['_ATTACHMENTFILTER_FILETYPE']._serialized_end=1177
# @@protoc_insertion_point(module_scope)



import logging

from ClientHolder import ClientHolder, OlvidAdminClient, datatypes

async def test_keycloak(client_holder: ClientHolder):
	# check if there keycloak identities
	keycloak_identities: list[datatypes.Identity] = [i async for i in client_holder.admin_client.admin_identity_list(filter=datatypes.IdentityFilter(keycloak=datatypes.IdentityFilter.Keycloak.KEYCLOAK_IS))]
	if len(keycloak_identities) == 0:
		logging.warning("No keycloak identities, skipping test")
		return

	for keycloak_identity in keycloak_identities:
		keycloak_client = OlvidAdminClient(identity_id=keycloak_identity.id)

		keycloak_user: list[datatypes.KeycloakUser] = []
		async for response in keycloak_client.keycloak_user_list():
			keycloak_user.extend(response[0])
		await keycloak_client.keycloak_get_api_credentials()



import asyncclick as click
from datetime import datetime

from olvid import datatypes
from ..interactive_tree import interactive_tree
from ..tools.ClientSingleton import ClientSingleton
from ..tools.cli_tools import print_normal_message, print_command_result, print_error_message
from ..tools.click_wrappers import WrapperGroup


#####
# backup
#####
@interactive_tree.group("backup", short_help="manage your daemon backups", cls=WrapperGroup)
async def backup_tree():
	pass

#####
# backup get
#####
@backup_tree.command("get", help="list backed up profiles and available snapshots")
@click.argument("backup_key", required=True, type=str)
async def backup_get(backup_key: str):
	if not ClientSingleton.is_client_admin():
		print_error_message("Cannot manage backups when impersonating a non admin key")
		return

	backup: datatypes.Backup = await ClientSingleton.get_client().admin_backup_get(backup_key=backup_key)
	print(f"=== Admin backup ===")
	print(f"admin_client_key_count: {backup.admin_backup.admin_client_key_count}")
	print(f"storage_elements_count: {backup.admin_backup.storage_elements_count}")

	for backup_profile in backup.profile_backups:
		print(f"=== {backup_profile.profile_display_name} (can be restored: {'❌' if backup_profile.already_exists_locally else '✅'}) {'(keycloak managed)'if backup_profile.keycloak_managed else ''} ===")
		snapshots: list[str] = []
		for snapshot in backup_profile.snapshots:
			snapshots.append(f"""  id: {snapshot.id}
  contact_count: {snapshot.contact_count}
  group_count: {snapshot.group_count}
  client_key_count: {snapshot.client_key_count}
  storage_elements_count: {snapshot.storage_elements_count}
  settings: {snapshot.identity_settings}
  timestamp: {datetime.fromtimestamp(snapshot.timestamp/1000).isoformat()}""")
		print("\n  -----\n".join(snapshots))

#####
# backup now
#####
@backup_tree.command("now", help="start a full backup now")
async def backup_now():
	if not ClientSingleton.is_client_admin():
		print_error_message("Cannot manage backups when impersonating a non admin key")
		return

	await ClientSingleton.get_client().admin_backup_now()
	print_command_result(f"Finished backup", "")

#####
# backup restore
#####
@backup_tree.group("restore", short_help="restore an entire backup on a new daemon or only specific parts", cls=WrapperGroup)
async def backup_restore_tree():
	pass

#####
# backup restore daemon
#####
@backup_restore_tree.command("daemon", help="restore an entire backup on blank daemon instance")
@click.argument("backup_key", required=True, type=str)
@click.option("-n", "--device-name", "device_name", default=None, type=click.STRING, help="Specify this new daemon instance name")
async def backup_restore_daemon(backup_key: str, device_name: str):
	if not ClientSingleton.is_client_admin():
		print_error_message("Cannot manage backups when impersonating a non admin key")
		return

	response = await ClientSingleton.get_client().admin_backup_restore_daemon(backup_key=backup_key, new_device_name=device_name)

	full_result: str = f"Restored identities:\n" + "\n".join([str(i) for i in response.restored_identities]) + "\n"
	full_result += f"Restored admin client keys:\n" + "\n".join(f"- {c.name}" for c in response.restored_admin_client_keys) + "\n"
	full_result += f"Restored client keys:\n" + "\n".join(f"- {c.name}" for c in response.restored_client_keys)

	script_result: str = "\n".join([str(i.id) for i in response.restored_identities])

	print_command_result(full_result, script_result)

#####
# backup restore admin
#####
@backup_restore_tree.command("admin", help="restore admin backup only (admin client keys and storage)")
@click.argument("backup_key", required=True, type=str)
async def backup_restore_admin(backup_key: str):
	if not ClientSingleton.is_client_admin():
		print_error_message("Cannot manage backups when impersonating a non admin key")
		return

	restored_admin_client_keys: list[datatypes.ClientKey] = await ClientSingleton.get_client().admin_backup_restore_admin_backup(backup_key=backup_key)
	print_command_result(f"Restored admin client keys:\n" + "\n".join(f"- {c.name}" for c in restored_admin_client_keys), str(len(restored_admin_client_keys)))

#####
# backup restore profile
#####
@backup_restore_tree.command("profile", help="restore a specific profile snapshot")
@click.argument("backup_key", required=True, type=str)
@click.argument("snapshot_id", required=True, type=str)
async def backup_restore_profile(backup_key: str, snapshot_id: str):
	if not ClientSingleton.is_client_admin():
		print_error_message("Cannot manage backups when impersonating a non admin key")
		return

	response = await ClientSingleton.get_client().admin_backup_restore_profile_snapshot(backup_key=backup_key, id=snapshot_id)
	print_command_result(f"Restored identity: {response.restored_identity}", str(response.restored_identity.id))

#####
# backup key
#####
@backup_tree.group("key", short_help="manage your daemon backup key", cls=WrapperGroup)
async def backup_key_tree():
	pass

#####
# backup key get
#####
@backup_key_tree.command("get", help="get current backup key (this key is common for every identity on this daemon)")
async def backup_key_get():
	if not ClientSingleton.is_client_admin():
		print_error_message("Cannot manage backups when impersonating a non admin key")
		return

	backup_key: str = await ClientSingleton.get_client().admin_backup_key_get()
	print_normal_message(backup_key, backup_key)

#####
# backup key renew
#####
@backup_key_tree.command("renew", help="revoke current backup key and generate a new one")
async def backup_key_renew():
	if not ClientSingleton.is_client_admin():
		print_error_message("Cannot manage backups when impersonating a non admin key")
		return

	backup_key: str = await ClientSingleton.get_client().admin_backup_key_renew()
	print_normal_message(backup_key, backup_key)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/invitation_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/invitation_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import invitation_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_invitation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;olvid/daemon/notification/v1/invitation_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a*olvid/daemon/datatypes/v1/invitation.proto\"\xa5\x01\n)SubscribeToInvitationReceivedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.InvitationFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"g\n\x1eInvitationReceivedNotification\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\"\xa1\x01\n%SubscribeToInvitationSentNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.InvitationFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"c\n\x1aInvitationSentNotification\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\"\xcb\x01\n(SubscribeToInvitationDeletedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.InvitationFilterH\x01R\x06\x66ilter\x88\x01\x01\x12%\n\x0einvitation_ids\x18\x03 \x03(\x04R\rinvitationIdsB\x08\n\x06_countB\t\n\x07_filter\"f\n\x1dInvitationDeletedNotification\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\"\xcb\x01\n(SubscribeToInvitationUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.InvitationFilterH\x01R\x06\x66ilter\x88\x01\x01\x12%\n\x0einvitation_ids\x18\x03 \x03(\x04R\rinvitationIdsB\x08\n\x06_countB\t\n\x07_filter\"\xd2\x01\n\x1dInvitationUpdatedNotification\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\x12j\n\x1aprevious_invitation_status\x18\x02 \x01(\x0e\x32,.olvid.daemon.datatypes.v1.Invitation.StatusR\x18previousInvitationStatusB\xe4\x01\n com.olvid.daemon.notification.v1B\x1cInvitationNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.invitation_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\034InvitationNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOINVITATIONRECEIVEDNOTIFICATION']._serialized_start=138
  _globals['_SUBSCRIBETOINVITATIONRECEIVEDNOTIFICATION']._serialized_end=303
  _globals['_INVITATIONRECEIVEDNOTIFICATION']._serialized_start=305
  _globals['_INVITATIONRECEIVEDNOTIFICATION']._serialized_end=408
  _globals['_SUBSCRIBETOINVITATIONSENTNOTIFICATION']._serialized_start=411
  _globals['_SUBSCRIBETOINVITATIONSENTNOTIFICATION']._serialized_end=572
  _globals['_INVITATIONSENTNOTIFICATION']._serialized_start=574
  _globals['_INVITATIONSENTNOTIFICATION']._serialized_end=673
  _globals['_SUBSCRIBETOINVITATIONDELETEDNOTIFICATION']._serialized_start=676
  _globals['_SUBSCRIBETOINVITATIONDELETEDNOTIFICATION']._serialized_end=879
  _globals['_INVITATIONDELETEDNOTIFICATION']._serialized_start=881
  _globals['_INVITATIONDELETEDNOTIFICATION']._serialized_end=983
  _globals['_SUBSCRIBETOINVITATIONUPDATEDNOTIFICATION']._serialized_start=986
  _globals['_SUBSCRIBETOINVITATIONUPDATEDNOTIFICATION']._serialized_end=1189
  _globals['_INVITATIONUPDATEDNOTIFICATION']._serialized_start=1192
  _globals['_INVITATIONUPDATEDNOTIFICATION']._serialized_end=1402
# @@protoc_insertion_point(module_scope)
